@@ -1513,6 +1513,9 @@ void _init_char(PyObject *m)
     INSTALL_ENUM(UBlockCode, "KAKTOVIK_NUMERALS", UBLOCK_KAKTOVIK_NUMERALS);
     INSTALL_ENUM(UBlockCode, "KAWI", UBLOCK_KAWI);
     INSTALL_ENUM(UBlockCode, "NAG_MUNDARI", UBLOCK_NAG_MUNDARI);
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(74, 0, 0)
+    INSTALL_ENUM(UBlockCode, "CJK_UNIFIED_IDEOGRAPHS_EXTENSION_I", UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_I);
 #endif
     INSTALL_ENUM(UBlockCode, "INVALID_CODE", UBLOCK_INVALID_CODE);
 
@@ -1699,6 +1702,28 @@ void _init_char(PyObject *m)
     INSTALL_ENUM(ULineBreak, "H3", U_LB_H3);
     INSTALL_ENUM(ULineBreak, "JL", U_LB_JL);
     INSTALL_ENUM(ULineBreak, "JT", U_LB_JT);
+#if U_ICU_VERSION_HEX >= 0x04040000
+    INSTALL_ENUM(ULineBreak, "CLOSE_PARENTHESIS", U_LB_CLOSE_PARENTHESIS);
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(49, 0, 0)
+    INSTALL_ENUM(ULineBreak, "CONDITIONAL_JAPANESE_STARTER", U_LB_CONDITIONAL_JAPANESE_STARTER);
+    INSTALL_ENUM(ULineBreak, "HEBREW_LETTER", U_LB_HEBREW_LETTER);
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(50, 0, 0)
+    INSTALL_ENUM(ULineBreak, "REGIONAL_INDICATOR", U_LB_REGIONAL_INDICATOR);
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(58, 0, 0)
+    INSTALL_ENUM(ULineBreak, "E_BASE", U_LB_E_BASE);
+    INSTALL_ENUM(ULineBreak, "E_MODIFIER", U_LB_E_MODIFIER);
+    INSTALL_ENUM(ULineBreak, "ZWJ", U_LB_ZWJ);
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(74, 0, 0)
+    INSTALL_ENUM(ULineBreak, "AKSARA_PREBASE", U_LB_AKSARA_PREBASE);
+    INSTALL_ENUM(ULineBreak, "AKSARA_START", U_LB_AKSARA_START);
+    INSTALL_ENUM(ULineBreak, "AKSARA", U_LB_AKSARA);
+    INSTALL_ENUM(ULineBreak, "VIRAMA_FINAL", U_LB_VIRAMA_FINAL);
+    INSTALL_ENUM(ULineBreak, "VIRAMA", U_LB_VIRAMA);
+#endif
 
     INSTALL_ENUM(UGraphemeClusterBreak, "OTHER", U_GCB_OTHER);
     INSTALL_ENUM(UGraphemeClusterBreak, "CONTROL", U_GCB_CONTROL);
@@ -1730,20 +1755,4 @@ void _init_char(PyObject *m)
     INSTALL_ENUM(UHangulSyllableType, "TRAILING_JAMO", U_HST_TRAILING_JAMO);
     INSTALL_ENUM(UHangulSyllableType, "LV_SYLLABLE", U_HST_LV_SYLLABLE);
     INSTALL_ENUM(UHangulSyllableType, "LVT_SYLLABLE", U_HST_LVT_SYLLABLE);
-
-#if U_ICU_VERSION_HEX >= 0x04040000
-    INSTALL_ENUM(ULineBreak, "CLOSE_PARENTHESIS", U_LB_CLOSE_PARENTHESIS);
-#endif
-#if U_ICU_VERSION_HEX >= VERSION_HEX(49, 0, 0)
-    INSTALL_ENUM(ULineBreak, "CONDITIONAL_JAPANESE_STARTER", U_LB_CONDITIONAL_JAPANESE_STARTER);
-    INSTALL_ENUM(ULineBreak, "HEBREW_LETTER", U_LB_HEBREW_LETTER);
-#endif
-#if U_ICU_VERSION_HEX >= VERSION_HEX(50, 0, 0)
-    INSTALL_ENUM(ULineBreak, "REGIONAL_INDICATOR", U_LB_REGIONAL_INDICATOR);
-#endif
-#if U_ICU_VERSION_HEX >= VERSION_HEX(58, 0, 0)
-    INSTALL_ENUM(ULineBreak, "E_BASE", U_LB_E_BASE);
-    INSTALL_ENUM(ULineBreak, "E_MODIFIER", U_LB_E_MODIFIER);
-    INSTALL_ENUM(ULineBreak, "ZWJ", U_LB_ZWJ);
-#endif
 }
